summaryrefslogtreecommitdiffhomepage
path: root/pkg/sentry/vfs/testutil.go
diff options
context:
space:
mode:
authorgVisor bot <gvisor-bot@google.com>2019-11-26 02:14:18 +0000
committergVisor bot <gvisor-bot@google.com>2019-11-26 02:14:18 +0000
commit9eb662f6bf2fb48eb9631002a1c8b5203dc455c7 (patch)
tree7f47a9ab12148edf3343f70b9c0fc18298c5915f /pkg/sentry/vfs/testutil.go
parent11b3c62c47beed4fd8f40177d06f3252fc641a08 (diff)
parentb72e1b3c0873ea29d031db42e39ca053923eecff (diff)
Merge release-20191114.0-35-gb72e1b3 (automated)
Diffstat (limited to 'pkg/sentry/vfs/testutil.go')
-rwxr-xr-xpkg/sentry/vfs/testutil.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/pkg/sentry/vfs/testutil.go b/pkg/sentry/vfs/testutil.go
index 70b192ece..593144cb7 100755
--- a/pkg/sentry/vfs/testutil.go
+++ b/pkg/sentry/vfs/testutil.go
@@ -33,10 +33,10 @@ type FDTestFilesystem struct {
vfsfs Filesystem
}
-// NewFilesystem implements FilesystemType.NewFilesystem.
-func (fstype FDTestFilesystemType) NewFilesystem(ctx context.Context, creds *auth.Credentials, source string, opts NewFilesystemOptions) (*Filesystem, *Dentry, error) {
+// GetFilesystem implements FilesystemType.GetFilesystem.
+func (fstype FDTestFilesystemType) GetFilesystem(ctx context.Context, vfsObj *VirtualFilesystem, creds *auth.Credentials, source string, opts GetFilesystemOptions) (*Filesystem, *Dentry, error) {
var fs FDTestFilesystem
- fs.vfsfs.Init(&fs)
+ fs.vfsfs.Init(vfsObj, &fs)
return &fs.vfsfs, fs.NewDentry(), nil
}
@@ -126,14 +126,14 @@ func (fs *FDTestFilesystem) NewDentry() *Dentry {
}
// IncRef implements DentryImpl.IncRef.
-func (d *fdTestDentry) IncRef(vfsfs *Filesystem) {
+func (d *fdTestDentry) IncRef() {
}
// TryIncRef implements DentryImpl.TryIncRef.
-func (d *fdTestDentry) TryIncRef(vfsfs *Filesystem) bool {
+func (d *fdTestDentry) TryIncRef() bool {
return true
}
// DecRef implements DentryImpl.DecRef.
-func (d *fdTestDentry) DecRef(vfsfs *Filesystem) {
+func (d *fdTestDentry) DecRef() {
}